AWS の準備
===============================
aws プロバイダを使用する場合は AWS マネジメントコンソールから hive-builder 用のユーザを作成して、そのアクセスキーを設定してください。
また、暗号化ボリュームを使用する場合は、暗号化鍵を設定してください。

1. ユーザグループの作成
----------------------------------------
ユーザにポリシーを適用するためにユーザグループを作成することをおすすめします。
ユーザグループを作成し、アクセス許可に組み込みポリシー AmazonEC2FullAccess および AWSKeyManagementServicePowerUser をアタッチしてください。

2. ユーザの作成
----------------------------------------
以下の手順でユーザを作成してください。

2-1. ユーザを追加ウィザードの起動
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
AWS マネジメントコンソールのIAMサービスで、「ユーザ」を開き、「ユーザを追加」ボタンをクリックしてユーザを追加ウィザードの起動してください。

2-2. ユーザを追加
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
ユーザ名を指定してください。ユーザ名は hive-builder 用のものであることが分かる名前にすることをおすすめします。
作成時の「AWS アクセスの種類を選択」で「プログラムによるアクセス」を選択してください。
「AWS マネジメントコンソールへのアクセス」は不要ですので、選択しないでください。
入力が完了したら、「次のステップ：アクセス権限」をクリックしてください。

2-2. アクセス権限
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
「ユーザをグループに追加」で手順1. で作成したユーザグループを選択してください。
入力が完了したら、「次のステップ：タグ」をクリックしてください。

2-3. タグ
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
hive-builder では特に必要なタグはありません。業務の都合に応じてタグを設定してください。
入力が完了したら、「次のステップ：確認」をクリックしてください。

2-4. 確認
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
内容を確認し問題がなければ、「ユーザの作成」をクリックしてください。

2-5. アクセスキーの取得
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
ユーザを追加に成功すると「成功」が表示され、アクセスキーIDとシークレットアクセスキーが表示されます。
シークレットアクセスキーが ****** となっている場合は「表示」をクリックして内容を表示してください。
アクセスキーIDとシークレットアクセスキーをコピーして hive-builder で以下のコマンドを実行して
設定してください。

::

  hive set aws_access_key_id アクセスキーID
  hive set aws_secret_access_key アクセスキー

3. EBS暗号化用の鍵の設定
----------------------------------------
AWS マネジメントコンソールのKMS（Key Management Service）にアクセスし、AWS マネージド型キーを開き、aws/ebs をクリックしてください。
これは、EBSを暗号化する際にデフォルトで利用されるマスタキーです。
この鍵のARNをコピーし hive定義の kms_key_id に設定してください。変数名が _id となっていますが、設定するのは ID ではなく、 ARN であることに注意してください。
ボリュームを暗号化する際は、以下のように disk_encrypted、mirrored_disk_encrypted、repository_disk_encrypted属性に True を指定してください。

::

    disk_encrypted: True
    mirrored_disk_encrypted: True
    repository_disk_encrypted: True
    kms_key_id: "aws/ebs鍵のARN"

ボリュームを暗号化しない場合はこの設定は不要です。disk_encrypted, mirrored_disk_encrypted, repository_disk_encrypted, kms_key_id 属性を省略してください。
